( cd opt/kde/share/doc/HTML/pt/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ark ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kig ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/juk ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/juk ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ktuberling ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/amor ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/karm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kate ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdvi ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kget ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kget ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kgpg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmag ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmid ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmix ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kodo ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kolf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpdf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/korn ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kppp ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/krdc ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/krdc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/krec ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/krfb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kscd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksim ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/lisa ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kxkb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kalzium ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/katomic ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksysguard ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kbounce ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdearch ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdearch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdelirc/kcmlirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdelirc/irkick ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kbattleship ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kaboodle ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/knewsticker ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/knewsticker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/khangman ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kfloppy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/cervisia ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/khexedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/khexedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpercentage ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kandy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcalc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdesu ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcron ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdict ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kfind ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kiten ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kiten ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kjots ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kjots ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmail ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmoon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/knode ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kooka ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksame ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksirc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ktnef ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ktnef ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksysv ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ktron ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kuser ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kview ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwin4 ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/lskat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/klipper ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmousetool ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kompare ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kontact ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/konsole ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/konsolekalendar ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpackage ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kshisen ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksirtet ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/konquest ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kturtle ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kturtle ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kverbos ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwallet ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kweather ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwuftpd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kioslave ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kxconfig ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kxconfig ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/pt/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kxmlrpcd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/artsbuilder ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kbabel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kalarm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kamera ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdeprint ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kasteroids ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kbruch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/keduca ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kgamma ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdevelop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdevelop ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kicker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/klatin ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/klatin ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/klines ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmines ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmouth ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmplot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/knotes ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpager ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kopete ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpilot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpoker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kruler ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ktalkd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksnake ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kspell ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kstars ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ktimer ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ktouch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwrite ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kreversi ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/noatun ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksplashml ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kblackbox ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kcharselect ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/quanta ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kuickshow ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kolourpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kde_app_devel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kommander ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kommander ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kiconedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/klettres ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kghostview ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/klickety ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kleopatra ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kenolaba ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwatchgnupg ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kworldclock ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/ksokoban ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kteatime ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kmathtool ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/umbrello ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/konqueror ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kwordquiz ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/korganizer ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/atlantik ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
